KeepManager class

Constructors

KeepManager()
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
perform({required String params, required TaskFunction function, int maxCount = 1}) → void
确保任务执行成功,若执行失败或异常则继续将任务添加至队首等待下次执行; maxCount 最多执行次数
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → KeepManager
no setter