KeepResponse class

Constructors

KeepResponse(String params, TaskFunction task, int currCount, int maxCount)

Properties

currCount ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
maxCount → int
final
params → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
task → TaskFunction
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited