LangConfigEntry class

Author lijinghuan Email:ljh0576123@163.com CreateTime:2021-12-24 Description:Generated file. Do not edit. Modifier: ModifyContent:

Constructors

LangConfigEntry({String langCode = '', String countryCode = '', bool isDefault = false, String unique = '', Map<String, dynamic>? json})
LangConfigEntry.fromJson(Map<String, dynamic> json)
factory

Properties

countryCode ↔ String
国家编码
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isDefault ↔ bool
是否默认语言
getter/setter pair
langCode ↔ String
语言编码
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unique ↔ String
语言包标识
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited