TextItem class

Author lijinghuan Email:ljh0576123@163.com CreateTime:2023-02-06 Description:Generated file. Do not edit. Modifier: ModifyContent:

Constructors

TextItem({Map<String, String> textMap = const {}, int weight = 0, Map<String, dynamic>? json})
TextItem.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textMap ↔ Map<String, String>
多语言map
getter/setter pair
weight ↔ int
权重值
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited