LogOutEvent class

Constructors

LogOutEvent({Level level = Level.info, List<String> lines = const []})

Properties

hashCode → int
The hash code for this object.
no setterinherited
level → Level
日志类别
final
lines → List<String>
本条日志输出行集合
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited